#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.12
id: uuid-1.3.12-2d400ebaa361b94ddb33df85f93ca791
key: uuid_6PwFfHICNju0Ut9rrA496c
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.12
library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.12
data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-1.3.12
hs-libraries: HSuuid-1.3.12-6PwFfHICNju0Ut9rrA496c
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
    network-info-0.2.0.8-bc6c8aa48b93ac2c06aa2e5c4fa39eb6
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    uuid-types-1.0.3-129ee1a49c60bed5953b3255a879f830
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
